// node >= 8
// babel == 6 plugin

const t = require('babel-types')
const { writeFile } = require('fs')
const { promisify } = require('util')

const CssImport = require('./css-import-visitor')
const {
  jsToAst, jsStringToAst, jssPathname, constAst, postcss,
  retreiveOptions,
} = require('./helpers')
const { defaultOptions } = require('./consts')

/* main() { */

module.exports = function(babel) {

  // is plugin initialized?
  let initialized = false

  const pluginApi = {
    manipulateOptions (options) {
      if (initialized) return options

      // e.g. { generateScopedName }
      const currentConfig = { ...defaultOptions, ...retreiveOptions(options, pluginApi) }

      console.log('conf', currentConfig)

      // TODO:
      // require('./postcss-hook')(currentConfig)
    },
    visitor: {
      ImportDeclaration: {
        exit: CssImport(({ src, css, classes, importNode, replaceWith, jssObject }) => {
          // debugger

          writeJssFile(jssObject, src)

          // TODO: check replaceWith API
          replaceWith([
            classesMapConstAst({ jssObject, css, classes, importNode }),
            jssCallAst({ src }),
          ])
        })
      }
    }
  }
  return pluginApi
}

/* } */

function writeJssFile(jssObject, fromSrc) {
  const jssObject = jssObject
  promisify(writeFile)(jssPathname(fromSrc), jssObject, 'utf8').catch(console.error)
}

function classesMapConstAst({ jssObject, css, importNode, classes: classesMap }) {
  // XXX: class-names API extending with jssObject (css-in-js object generated on source css)
  classesMap.jssObject = jssObject
  const classesMapAst = jsToAst(classesMap)
  const classesMapVarNameAst = t.identifier(importNode.local.name)

  return constAst(classesMapVarNameAst, classesMapAst)
}

function jssCallAst({ src }) {
  // TODO: create common jssEmptyPreset
  jsStringToAst(`require('jss').create(jssEmptyPreset()).createStyleSheet(require('${ jssPathname(src) }'))`)
}
