// node >= 8
// babel == 6 plugin

const t = require('babel-types');
const { writeFile } = require('fs');
const { promisify } = require('util');

const CssImport = require('./css-import-visitor');
const {
  jsToAst, jsStringToAst, jssPathname, constAst, postcss, cssToJss,
  retreiveOptions,
} = require('./helpers');

const { defaultOptions } = require('./consts');

/* main() { */

module.exports = function(babel) {
  // is plugin initialized?
  const initialized = false;

  const pluginApi = {
    manipulateOptions (options) {
      // if (initialized) return options;
      return options;

      // e.g. { generateScopedName }
      // const currentConfig = { ...defaultOptions, ...retreiveOptions(options, pluginApi) };

      // TODO:
      // require('./postcss-hook')(currentConfig)
      // const initialized = true;
    },
    visitor: {
      ImportDeclaration: {
        exit: CssImport(({ src, css, opts, importNode, replaceWith }) => {
          const { code, classes } = postcss.process(css, src, opts);
          const jssObject = cssToJss({ code });

          writeJssFile(jssObject, src);

          // TODO: check replaceWith API
          replaceWith([
            classesMapConstAst({ jssObject, classes, importNode }),
            jssCallAst({ src }),
          ]);
        }),
      },
    },
  };
  return pluginApi;
};

/* } */

function writeJssFile(jssObject, fromSrc) {
  promisify(writeFile)(jssPathname(fromSrc), jssObject, 'utf8').catch(console.error);
}

function classesMapConstAst({ jssObject, importNode, classes: classesMap }) {
  // XXX: class-names API extending with jssObject (css-in-js object generated on source css)
  classesMap.jssObject = jssObject;
  const classesMapAst = jsToAst(classesMap);
  const classesMapVarNameAst = t.identifier(importNode.local.name);

  return constAst(classesMapVarNameAst, classesMapAst);
}

function jssCallAst({ src }) {
  // TODO: create common jssEmptyPreset
  jsStringToAst(`require('jss').create(jssEmptyPreset()).createStyleSheet(require('${ jssPathname(src) }'))`);
}
